==> jc-1.4.0.tar.gz: soot/jimple/parser/node/ASingleArgList.h <==
// public final class soot.jimple.parser.node.ASingleArgList

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class fdad2d7ed597a6d1 soot_jimple_parser_node_ASingleArgList
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class a9fcdf910e95e23b soot_jimple_parser_node_PArgList

// header file dependencies
// @dep_header soot_jimple_parser_node_PArgList

#include "soot/jimple/parser/node/PArgList.h"

#ifndef _JC_soot_jimple_parser_node_ASingleArgList_H_
#define _JC_soot_jimple_parser_node_ASingleArgList_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_PImmediate$object;
struct _jc_soot_jimple_parser_node_Switch$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_ASingleArgList$sub_refs	_jc_soot_jimple_parser_node_ASingleArgList$sub_refs;
typedef struct _jc_soot_jimple_parser_node_ASingleArgList$sub_nonrefs	_jc_soot_jimple_parser_node_ASingleArgList$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_ASingleArgList$refs	_jc_soot_jimple_parser_node_ASingleArgList$refs;
typedef struct _jc_soot_jimple_parser_node_ASingleArgList$nonrefs	_jc_soot_jimple_parser_node_ASingleArgList$nonrefs;
typedef struct _jc_soot_jimple_parser_node_ASingleArgList$object	_jc_soot_jimple_parser_node_ASingleArgList$object;

typedef const struct _jc_soot_jimple_parser_node_ASingleArgList$vmethods	_jc_soot_jimple_parser_node_ASingleArgList$vmethods;
typedef const struct _jc_soot_jimple_parser_node_ASingleArgList$vtable	_jc_soot_jimple_parser_node_ASingleArgList$vtable;
typedef const struct _jc_soot_jimple_parser_node_ASingleArgList$vtype	_jc_soot_jimple_parser_node_ASingleArgList$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_ASingleArgList$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_ASingleArgList$object *);
extern void _jc_soot_jimple_parser_node_ASingleArgList$method$_init$913b23eff972c09c(_jc_env *, struct _jc_soot_jimple_parser_node_ASingleArgList$object *, struct _jc_soot_jimple_parser_node_PImmediate$object *);

// Virtual methods
extern void _jc_soot_jimple_parser_node_ASingleArgList$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_ASingleArgList$object *, struct _jc_object *);
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_ASingleArgList$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_ASingleArgList$object *);
extern struct _jc_soot_jimple_parser_node_PImmediate$object *_jc_soot_jimple_parser_node_ASingleArgList$method$getImmediate$0661c89577f08ebf(_jc_env *, struct _jc_soot_jimple_parser_node_ASingleArgList$object *);
extern void _jc_soot_jimple_parser_node_ASingleArgList$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_ASingleArgList$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_ASingleArgList$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_ASingleArgList$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_ASingleArgList$method$setImmediate$8ed5e501ae03baef(_jc_env *, struct _jc_soot_jimple_parser_node_ASingleArgList$object *, struct _jc_soot_jimple_parser_node_PImmediate$object *);
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_ASingleArgList$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_ASingleArgList$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_ASingleArgList$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_ASingleArgList$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_ASingleArgList$method_info$getImmediate$0661c89577f08ebf;
extern _jc_method _jc_soot_jimple_parser_node_ASingleArgList$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_ASingleArgList$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_ASingleArgList$method_info$setImmediate$8ed5e501ae03baef;
extern _jc_method _jc_soot_jimple_parser_node_ASingleArgList$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_ASingleArgList$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_ASingleArgList$object *, struct _jc_object *);
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_ASingleArgList$object *);
	struct _jc_soot_jimple_parser_node_PImmediate$object	*(*getImmediate$0661c89577f08ebf)(_jc_env *, struct _jc_soot_jimple_parser_node_ASingleArgList$object *);
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_ASingleArgList$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_ASingleArgList$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*setImmediate$8ed5e501ae03baef)(_jc_env *, struct _jc_soot_jimple_parser_node_ASingleArgList$object *, struct _jc_soot_jimple_parser_node_PImmediate$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_ASingleArgList$object *);
};

// Vtable
struct _jc_soot_jimple_parser_node_ASingleArgList$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PArgList$vmethods	soot_jimple_parser_node_PArgList;
	_jc_soot_jimple_parser_node_ASingleArgList$vmethods	soot_jimple_parser_node_ASingleArgList;
};

// Vtype
struct _jc_soot_jimple_parser_node_ASingleArgList$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_ASingleArgList$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ASingleArgList$sub_refs {
	struct _jc_soot_jimple_parser_node_PImmediate$object	*__5fimmediate__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_ASingleArgList$refs {
    _jc_soot_jimple_parser_node_ASingleArgList$sub_refs	soot_jimple_parser_node_ASingleArgList;
    _jc_soot_jimple_parser_node_PArgList$sub_refs	soot_jimple_parser_node_PArgList;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ASingleArgList$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_ASingleArgList$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PArgList$sub_nonrefs	soot_jimple_parser_node_PArgList;
    _jc_soot_jimple_parser_node_ASingleArgList$sub_nonrefs	soot_jimple_parser_node_ASingleArgList;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_ASingleArgList$object {
	_jc_soot_jimple_parser_node_ASingleArgList$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_ASingleArgList$vtype	*vtype;
	_jc_soot_jimple_parser_node_ASingleArgList$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_ASingleArgList$vtype _jc_soot_jimple_parser_node_ASingleArgList$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_ASingleArgList, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_ASingleArgList$class_object;

#endif	/* _JC_soot_jimple_parser_node_ASingleArgList_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/parser/node/ASingleArgList.h <==
// public final class soot.jimple.parser.node.ASingleArgList

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class fdad2d7ed597a6d1 soot_jimple_parser_node_ASingleArgList
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class a9fcdf910e95e23b soot_jimple_parser_node_PArgList

// header file dependencies
// @dep_header soot_jimple_parser_node_PArgList

#include "soot/jimple/parser/node/PArgList.h"

#ifndef _JC_soot_jimple_parser_node_ASingleArgList_H_
#define _JC_soot_jimple_parser_node_ASingleArgList_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_PImmediate$object;
struct _jc_soot_jimple_parser_node_Switch$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_ASingleArgList$sub_refs	_jc_soot_jimple_parser_node_ASingleArgList$sub_refs;
typedef struct _jc_soot_jimple_parser_node_ASingleArgList$sub_nonrefs	_jc_soot_jimple_parser_node_ASingleArgList$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_ASingleArgList$refs	_jc_soot_jimple_parser_node_ASingleArgList$refs;
typedef struct _jc_soot_jimple_parser_node_ASingleArgList$nonrefs	_jc_soot_jimple_parser_node_ASingleArgList$nonrefs;
typedef struct _jc_soot_jimple_parser_node_ASingleArgList$object	_jc_soot_jimple_parser_node_ASingleArgList$object;

typedef const struct _jc_soot_jimple_parser_node_ASingleArgList$vmethods	_jc_soot_jimple_parser_node_ASingleArgList$vmethods;
typedef const struct _jc_soot_jimple_parser_node_ASingleArgList$vtable	_jc_soot_jimple_parser_node_ASingleArgList$vtable;
typedef const struct _jc_soot_jimple_parser_node_ASingleArgList$vtype	_jc_soot_jimple_parser_node_ASingleArgList$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_ASingleArgList$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_ASingleArgList$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_ASingleArgList$method$_init$913b23eff972c09c(_jc_env *, struct _jc_soot_jimple_parser_node_ASingleArgList$object *, struct _jc_soot_jimple_parser_node_PImmediate$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_parser_node_ASingleArgList$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_ASingleArgList$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_ASingleArgList$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_ASingleArgList$object *) _JC_JCNI_ATTR;
extern struct _jc_soot_jimple_parser_node_PImmediate$object *_jc_soot_jimple_parser_node_ASingleArgList$method$getImmediate$0661c89577f08ebf(_jc_env *, struct _jc_soot_jimple_parser_node_ASingleArgList$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_ASingleArgList$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_ASingleArgList$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_ASingleArgList$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_ASingleArgList$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_ASingleArgList$method$setImmediate$8ed5e501ae03baef(_jc_env *, struct _jc_soot_jimple_parser_node_ASingleArgList$object *, struct _jc_soot_jimple_parser_node_PImmediate$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_ASingleArgList$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_ASingleArgList$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_ASingleArgList$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_ASingleArgList$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_ASingleArgList$method_info$getImmediate$0661c89577f08ebf;
extern _jc_method _jc_soot_jimple_parser_node_ASingleArgList$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_ASingleArgList$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_ASingleArgList$method_info$setImmediate$8ed5e501ae03baef;
extern _jc_method _jc_soot_jimple_parser_node_ASingleArgList$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_ASingleArgList$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_ASingleArgList$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_ASingleArgList$object *) _JC_JCNI_ATTR;
	struct _jc_soot_jimple_parser_node_PImmediate$object	*(*getImmediate$0661c89577f08ebf)(_jc_env *, struct _jc_soot_jimple_parser_node_ASingleArgList$object *) _JC_JCNI_ATTR;
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_ASingleArgList$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_ASingleArgList$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*setImmediate$8ed5e501ae03baef)(_jc_env *, struct _jc_soot_jimple_parser_node_ASingleArgList$object *, struct _jc_soot_jimple_parser_node_PImmediate$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_ASingleArgList$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_parser_node_ASingleArgList$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PArgList$vmethods	soot_jimple_parser_node_PArgList;
	_jc_soot_jimple_parser_node_ASingleArgList$vmethods	soot_jimple_parser_node_ASingleArgList;
};

// Vtype
struct _jc_soot_jimple_parser_node_ASingleArgList$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_ASingleArgList$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ASingleArgList$sub_refs {
	struct _jc_soot_jimple_parser_node_PImmediate$object	*__5fimmediate__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_ASingleArgList$refs {
    _jc_soot_jimple_parser_node_ASingleArgList$sub_refs	soot_jimple_parser_node_ASingleArgList;
    _jc_soot_jimple_parser_node_PArgList$sub_refs	soot_jimple_parser_node_PArgList;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ASingleArgList$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_ASingleArgList$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PArgList$sub_nonrefs	soot_jimple_parser_node_PArgList;
    _jc_soot_jimple_parser_node_ASingleArgList$sub_nonrefs	soot_jimple_parser_node_ASingleArgList;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_ASingleArgList$object {
	_jc_soot_jimple_parser_node_ASingleArgList$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_ASingleArgList$vtype	*vtype;
	_jc_soot_jimple_parser_node_ASingleArgList$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_ASingleArgList$vtype _jc_soot_jimple_parser_node_ASingleArgList$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_ASingleArgList, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_ASingleArgList$class_object;

#endif	/* _JC_soot_jimple_parser_node_ASingleArgList_H_ */
